@@ -6,14 +6,16 @@ import logging
 import subprocess
 import time
 from pathlib import Path
-from typing import Optional, Dict, List, Any
+from typing import Optional, List
 
 from rich.console import Console
 
-from machineconfig.utils.utils5 import Scheduler
+from machineconfig.cluster.sessions_managers.zellij_utils.monitoring_types import SessionReport, GlobalSummary, StartResult, ActiveSessionInfo, StatusRow
+from machineconfig.utils.scheduler import Scheduler
 from machineconfig.cluster.sessions_managers.zellij_local import ZellijLayoutGenerator
 from machineconfig.utils.schemas.layouts.layout_types import LayoutConfig
 
+
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 console = Console()
@@ -24,16 +26,8 @@ TMP_SERIALIZATION_DIR = Path.home().joinpath("tmp_results", "session_manager", "
 class ZellijLocalManager:
     """Manages multiple local zellij sessions and monitors their tabs and processes."""
 
-    def __init__(self, session_layouts: list[LayoutConfig], session_name_prefix: str = "LocalJobMgr"):
-        """
-        Initialize the local zellij manager.
-
-        Args:
-            session_layouts: Dict mapping session names to their layout configs
-                Format: {session_name: LayoutConfig, ...}
-            session_name_prefix: Prefix for session names
-        """
-        self.session_name_prefix = session_name_prefix
+    def __init__(self, session_layouts: list[LayoutConfig]):
+        self.session_name_prefix = "LocalJobMgr"
         self.session_layouts = session_layouts  # Store the original config
         self.managers: List[ZellijLayoutGenerator] = []
 
@@ -42,7 +36,7 @@ class ZellijLocalManager:
             session_name = layout_config["layoutName"].replace(" ", "_")
             manager = ZellijLayoutGenerator()
             full_session_name = f"{self.session_name_prefix}_{session_name}"
-            manager.create_zellij_layout(layout_config=layout_config, session_name=full_session_name)
+            manager.create_zellij_layout(layout_config=layout_config, output_dir=None, session_name=full_session_name)
             self.managers.append(manager)
 
         # Enhanced Rich logging for initialization
@@ -52,7 +46,7 @@ class ZellijLocalManager:
         """Get all managed session names."""
         return [manager.session_name for manager in self.managers if manager.session_name is not None]
 
-    def start_all_sessions(self, poll_seconds: float = 5.0, poll_interval: float = 0.25) -> Dict[str, Any]:
+    def start_all_sessions(self, poll_seconds: float, poll_interval: float) -> dict[str, StartResult]:
         """Start all zellij sessions with their layouts without blocking on the interactive TUI.
 
         Rationale:
@@ -68,7 +62,7 @@ class ZellijLocalManager:
         Returns:
             Dict mapping session name to success metadata.
         """
-        results: Dict[str, Any] = {}
+        results: dict[str, StartResult] = {}
         for manager in self.managers:
             session_name = manager.session_name
             try:
@@ -118,20 +112,17 @@ class ZellijLocalManager:
                 logger.error(f"❌ Exception starting session '{key}': {e}")
         return results
 
-    def kill_all_sessions(self) -> Dict[str, Any]:
+    def kill_all_sessions(self) -> dict[str, StartResult]:
         """Kill all managed zellij sessions."""
-        results = {}
+        results: dict[str, StartResult] = {}
         for manager in self.managers:
             try:
                 session_name = manager.session_name
                 if session_name is None:
                     continue  # Skip managers without a session name
-
                 cmd = f"zellij delete-session --force {session_name}"
-
                 logger.info(f"Killing session '{session_name}'")
                 result = subprocess.run(cmd, shell=True, capture_output=True, text=True, timeout=10)
-
                 results[session_name] = {"success": result.returncode == 0, "message": "Session killed" if result.returncode == 0 else result.stderr}
 
             except Exception as e:
@@ -141,7 +132,7 @@ class ZellijLocalManager:
 
         return results
 
-    def attach_to_session(self, session_name: Optional[str] = None) -> str:
+    def attach_to_session(self, session_name: Optional[str]) -> str:
         """
         Generate command to attach to a specific session or list attachment commands for all.
 
@@ -159,16 +150,16 @@ class ZellijLocalManager:
             raise ValueError(f"Session '{session_name}' not found")
         else:
             # Return commands for all sessions
-            commands = []
+            commands: list[str] = []
             for manager in self.managers:
                 commands.append(f"# Attach to session '{manager.session_name}':")
                 commands.append(f"zellij attach {manager.session_name}")
                 commands.append("")
             return "\n".join(commands)
 
-    def check_all_sessions_status(self) -> Dict[str, Dict[str, Any]]:
+    def check_all_sessions_status(self) -> dict[str, SessionReport]:
         """Check the status of all sessions and their commands."""
-        status_report = {}
+        status_report: dict[str, SessionReport] = {}
 
         for manager in self.managers:
             session_name = manager.session_name
@@ -193,7 +184,7 @@ class ZellijLocalManager:
 
         return status_report
 
-    def get_global_summary(self) -> Dict[str, Any]:
+    def get_global_summary(self) -> GlobalSummary:
         """Get a global summary across all sessions."""
         all_status = self.check_all_sessions_status()
 
@@ -259,12 +250,13 @@ class ZellijLocalManager:
 
         print("=" * 80)
 
-    def run_monitoring_routine(self, wait_ms: int = 30000) -> None:
+    def run_monitoring_routine(self, wait_ms: int) -> None:
         """
         Run a continuous monitoring routine that checks status periodically.
 
         Args:
-            wait_ms: How long to wait between checks in milliseconds (default: 30000ms = 30s)
+            wait_ms: How long to wait between checks in milliseconds
+            kill_sessions_on_completion: If True, kill all managed zellij sessions when monitoring stops
         """
 
         def routine(scheduler: Scheduler):
@@ -276,7 +268,7 @@ class ZellijLocalManager:
                 all_status = self.check_all_sessions_status()
 
                 # Create DataFrame for easier viewing
-                status_data = []
+                status_data: list[StatusRow] = []
                 for session_name, status in all_status.items():
                     for tab_name, cmd_status in status["commands_status"].items():
                         status_data.append(
@@ -306,7 +298,8 @@ class ZellijLocalManager:
                     running_count = sum(1 for row in status_data if row.get("running", False))
                     if running_count == 0:
                         print("\n⚠️  All commands have stopped. Stopping monitoring.")
-                        scheduler.max_cycles = scheduler.cycle
+                        # Set max_cycles to current cycle + 1 to exit after this cycle
+                        scheduler.max_cycles = scheduler.cycle + 1
                         return
                 else:
                     print("No status data available")
@@ -319,7 +312,7 @@ class ZellijLocalManager:
         sched = Scheduler(routine=routine, wait_ms=wait_ms, logger=logger)
         sched.run()
 
-    def save(self, session_id: Optional[str] = None) -> str:
+    def save(self, session_id: Optional[str]) -> str:
         """Save the manager state to disk."""
         if session_id is None:
             session_id = str(uuid.uuid4())[:8]
@@ -365,19 +358,11 @@ class ZellijLocalManager:
         if not config_file.exists():
             raise FileNotFoundError(f"Configuration file not found: {config_file}")
 
-        with open(config_file, "r", encoding="utf-8") as f:
-            session_layouts = json.load(f)
-
-        # Load metadata
-        metadata_file = session_dir / "metadata.json"
-        session_name_prefix = "LocalJobMgr"  # default fallback
-        if metadata_file.exists():
-            with open(metadata_file, "r", encoding="utf-8") as f:
-                metadata = json.load(f)
-                session_name_prefix = metadata.get("session_name_prefix", "LocalJobMgr")
+        text = config_file.read_text(encoding="utf-8")
+        session_layouts = json.loads(text)
 
         # Create new instance
-        instance = cls(session_layouts=session_layouts, session_name_prefix=session_name_prefix)
+        instance = cls(session_layouts=session_layouts)
 
         # Load saved manager states
         managers_dir = session_dir / "managers"
@@ -387,8 +372,8 @@ class ZellijLocalManager:
 
             for manager_file in manager_files:
                 try:
-                    with open(manager_file, "r", encoding="utf-8") as f:
-                        manager_data = json.load(f)
+                    text = manager_file.read_text(encoding="utf-8")
+                    manager_data = json.loads(text)
 
                     # Recreate the manager
                     manager = ZellijLayoutGenerator()
@@ -436,9 +421,9 @@ class ZellijLocalManager:
             logger.error(f"Failed to delete session {session_id}: {e}")
             return False
 
-    def list_active_sessions(self) -> List[Dict[str, Any]]:
+    def list_active_sessions(self) -> list[ActiveSessionInfo]:
         """List currently active zellij sessions managed by this instance."""
-        active_sessions = []
+        active_sessions: list[ActiveSessionInfo] = []
 
         try:
             # Get all running zellij sessions
@@ -498,7 +483,7 @@ if __name__ == "__main__":
     ]
     try:
         # Create the local manager
-        manager = ZellijLocalManager(sample_sessions, session_name_prefix="DevEnv")
+        manager = ZellijLocalManager(sample_sessions)
         print(f"✅ Local manager created with {len(manager.managers)} sessions")
 
         # Show session names
@@ -506,7 +491,7 @@ if __name__ == "__main__":
 
         # Print attachment commands (without actually starting)
         print("\n📎 Attachment commands:")
-        print(manager.attach_to_session())
+        print(manager.attach_to_session(None))
 
         # Show current status
         print("\n🔍 Current status:")
@@ -514,7 +499,7 @@ if __name__ == "__main__":
 
         # Demonstrate save/load
         print("\n💾 Demonstrating save/load...")
-        session_id = manager.save()
+        session_id = manager.save(None)
         print(f"✅ Saved session: {session_id}")
 
         # List saved sessions
@@ -528,6 +513,8 @@ if __name__ == "__main__":
         # Show how to start monitoring (commented out to prevent infinite loop in demo)
         print("\n⏰ To start monitoring, run:")
         print("manager.run_monitoring_routine(wait_ms=30000)  # 30 seconds")
+        print("# Or with session cleanup:")
+        print("manager.run_monitoring_routine(wait_ms=30000, kill_sessions_on_completion=True)")
 
     except Exception as e:
         print(f"❌ Error: {e}")
