@@ -5,12 +5,6 @@ in the event that username@github.com is not mentioned in the remote url.
 
 """
 
-from machineconfig.utils.io import read_ini
-from machineconfig.utils.source_of_truth import CONFIG_PATH, DEFAULTS_PATH
-from machineconfig.utils.path_extended import PathExtended as PathExtended
-from machineconfig.scripts.python.repos_helper_record import main as record_repos
-from machineconfig.scripts.python.repos_helper_clone import clone_repos
-from machineconfig.scripts.python.repos_helper_action import perform_git_operations
 
 import typer
 from typing import Annotated, Optional
@@ -34,6 +28,13 @@ def main(
     print("📂 Welcome to the Repository Manager")
     print("=" * 50 + "\n")
 
+    from machineconfig.utils.io import read_ini
+    from machineconfig.utils.source_of_truth import CONFIG_PATH, DEFAULTS_PATH
+    from machineconfig.utils.path_extended import PathExtended as PathExtended
+    from machineconfig.scripts.python.repos_helper_record import main as record_repos
+    from machineconfig.scripts.python.repos_helper_clone import clone_repos
+    from machineconfig.scripts.python.repos_helper_action import perform_git_operations
+
     if directory == "":
         repos_root = PathExtended.home().joinpath("code")  # it is a positional argument, can never be empty.
     else:
@@ -60,7 +61,6 @@ def main(
         clone_repos(spec_path=repos_root, preferred_remote=None, checkout_branch_flag=checkout_to_branch, checkout_commit_flag=checkout)
 
     elif all or commit or pull or push:
-        # Use the new helper function for git operations
         perform_git_operations(
             repos_root=repos_root,
             pull=pull or all,
@@ -70,7 +70,12 @@ def main(
             auto_sync=auto_sync
         )
     else:
-        print("❌ No action specified. Try passing --push, --pull, --commit, or --all.")
+        # print("❌ No action specified. Try passing --push, --pull, --commit, or --all.")
+        typer.echo("❌ No action specified. Try passing --push, --pull, --commit, or --all.")
+        import click
+        ctx = click.get_current_context()
+        typer.echo(ctx.get_help())
+        raise typer.Exit(1)
 
 
 def main_from_parser() -> None:
